@@ -1,8 +1,8 @@
 
 #
 # lava.tcl
-# Copyright (C) 1998-2000 by John Heidemann
-# $Id: lava.tcl,v 1.47 2000/07/30 01:01:20 johnh Exp $
+# Copyright (C) 1998-2001 by John Heidemann
+# $Id: lava.tcl,v 1.51 2001/08/15 15:15:49 johnh Exp $
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License,
@@ -30,7 +30,14 @@ proc init_canvas {} {
 	canvas .c -width 100 -height 200 -bg black
 	pack append . .c {expand fill}
 
-	bind . <Configure> "canvas_configure %W %w %h %B"
+	bind . <Configure> "canvas_configure %W %w %h %B C"
+	# For me with sawfish, focusin/out events cause my 
+	# window to have its border redrawn, so I have to
+	# reconfigure things to get the shape back.  Ick.
+	bind . <FocusIn> "canvas_configure %W %w %h %B FI"
+	bind . <FocusOut> "canvas_configure %W %w %h %B FO"
+	bind . <Map> "canvas_configure %W %w %h %B M"
+
 	#
 	# canvas support
 	#
@@ -47,15 +54,30 @@ proc init_canvas {} {
 	}
 }
 
-proc canvas_configure {W w h B} {
+proc canvas_configure {W w h B why} {
+	global old_canvas_w old_canvas_h rdb
+
 	if {"$W" != "."} {
 		return
 	}
 
 	## I used to suppress non-resizes, but no more because
 	## it conflicts with lots of things.
-	lava_resize $w $h [wm frame .]
+	if {$why != "C"} {
+		# Focus in/out don't have size, so fake it.
+		set w $old_canvas_w
+		set h $old_canvas_h
+		set b 0
+	}
 	. configure -height $h -width $w
+	if {![info exists rdb(swallowed)]} {
+		set_rdb_default_boolean swallowed 0
+	}
+	if {$rdb(swallowed)} {
+		lava_resize $w $h
+	} else {
+		lava_resize $w $h [wm frame .]
+	}
 	set old_canvas_w $w
 	set old_canvas_h $h
 
@@ -212,9 +234,9 @@ proc debugging {} {
 proc send_signal {kind} {
 	global proc_menu_pid
 	if {[catch {lava_menu signal $kind $proc_menu_pid} dummy]} {
-		splash_refresh "Cannot signal"
+		splash_refresh "Cannot signal\n"
 	} else {
-		splash_refresh "Signaled"
+		splash_refresh "Signaled\n"
 	}
 }
 
