@@ -1,8 +1,8 @@
 proc init_help {} { global help
 	set help(about) {
-<big>Lavaps 1.15</big>
+<big>Lavaps 1.19</big>
 
-Copyright (C) 1998-2000 by John Heidemann. All rights reserved. Comments to <computer>johnh@isi.edu</computer>, latest version at <computer>http://www.isi.edu/~johnh/SOFTWARE/LAVAPS/</computer>.
+Copyright (C) 1998-2001 by John Heidemann. All rights reserved. Comments to <computer>johnh@isi.edu</computer>, latest version at <computer>http://www.isi.edu/~johnh/SOFTWARE/LAVAPS/</computer>.
 
 
 <big>Description</big>
@@ -72,7 +72,7 @@ The following resources are supported:
 
 <italic>geometry</italic>  (default none). Specifies the initial window location and size in X-style (see X(1)).
 
-<italic>who</italic>  (default me). Whose processes should we be watching, anyway? My processes (set to ``me'') or everyones (set to... ``everyone''). Can also be the process id of a single process if you're very single-minded.
+<italic>who</italic>  (default me). Whose processes should we be watching, anyway? My processes (set to ``me'') or everyone's (set to... ``everyone''). Can also be the process id of a single process if you're very single-minded.
 
 <italic>what</italic>  (default both). What kind of memory should blob size correspond to, either both, physical, or virtual.
 
@@ -104,5 +104,23 @@ You should have received a copy of the GNU General Public License along with thi
 
 
 
+}
+	set help(howdoi) {
+<big>How Do I...</big>
+
+Q: The blobs are as jumpy as little rabbits, <italic>How do I make the animation smoother?</italic>
+
+A: Set the checkInterval resource to a smaller value.
+
+Q: I'm running lavaps on my Timex Sinclair and it consumes a lot of CPU, making my editor ed run slowly. <italic>How can I make lavaps take less CPU?</italic>
+
+A: Set the checkInterval resource to a larger value.
+
+Q: Lozenge-shaped lavaps is so cool, but I keep loosing it on my 8000-pixel wide xinerama multi-screen display. <italic>How can I resize lozenge-shaped lavaps since it doesn't have any title bar?</italic>
+
+A: (1) Read your window manager documentation, most have ways to resize windows other than the title bar (sometimes using a menu).  (2) Set the geometry explicitly with the -geometry command-line option or the geometry resource.  (3) Put the title bar back (unfortunately loosing the lozenge shape) by setting the ``shaped'' resource to ``false''.
+
+
+
 }
 }
