@@ -1,8 +1,8 @@
 
 /*
  * main.cc
- * Copyright (C) 1999-2000 by John Heidemann
- * $Id: main.cc,v 1.20 2000/02/12 05:11:21 johnh Exp $
+ * Copyright (C) 1999-2001 by John Heidemann
+ * $Id: main.cc,v 1.21 2001/08/15 15:15:29 johnh Exp $
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License,
@@ -20,6 +20,8 @@
  */
 
 
+#include "config.h"
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <iostream.h>
@@ -100,6 +102,10 @@ parse_args(int argc, char **argv)
 		} else if (strcmp(argv[i], "-geometry") == 0 && optarg) {
 			default_resources += "lavaps.geometry: ";
 			default_resources += optarg;
+			default_resources += "\n";
+			i++;
+		} else if (strcmp(argv[i], "-swallowed") == 0) {
+			default_resources += "lavaps.swallowed: false\n";
 			i++;
 		} else {
 			usage();
